==> csmash_0.6.4.2.orig.tar.gz: csmash-0.6.4.2/SoloPlay.h <==
/* $Id: SoloPlay.h,v 1.6 2001/09/19 14:01:08 nan Exp $ */

// Copyright (C) 2000  $B?@Fn(B $B5H9((B(Kanna Yoshihiro)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#ifndef _SoloPlay_
#define _SoloPlay_
#include "PlayGame.h"

class SoloPlay : public PlayGame {
public:
  SoloPlay();
  virtual ~SoloPlay();

  virtual bool Init();

  static void Create( long player, long com );

  virtual bool Move( unsigned long *KeyHistory, long *MouseXHistory,
		     long *MouseYHistory, unsigned long *MouseBHistory,
		     int Histptr );

  long GetSmashPtr() { return m_smashPtr; };

  virtual bool LookAt( double &srcX, double &srcY, double &srcZ,
		       double &destX, double &destY, double &destZ );
  long SmashEffect( bool start, long histPtr );

protected:
  bool m_smash;
  long m_smashCount;
  long m_smashPtr;
};

#endif	// _SoloPlay_

==> csmash_0.6.6.orig.tar.gz: csmash-0.6.6/SoloPlay.h <==
/* $Id: SoloPlay.h,v 1.7 2003/07/16 15:59:10 nan Exp $ */

// Copyright (C) 2000  $B?@Fn(B $B5H9((B(Kanna Yoshihiro)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#ifndef _SoloPlay_
#define _SoloPlay_
#include "PlayGame.h"

class SoloPlay : public PlayGame {
public:
  SoloPlay();
  virtual ~SoloPlay();

  virtual bool Init();

  static void Create( long player, long com );

  virtual bool Move( SDL_keysym *KeyHistory, long *MouseXHistory,
		     long *MouseYHistory, unsigned long *MouseBHistory,
		     int Histptr );

  long GetSmashPtr() { return m_smashPtr; };

  virtual bool LookAt( double &srcX, double &srcY, double &srcZ,
		       double &destX, double &destY, double &destZ );
  long SmashEffect( bool start, long histPtr );

protected:
  bool m_smash;
  long m_smashCount;
  long m_smashPtr;

  void ReplayAction( int &Histptr );
};

#endif	// _SoloPlay_
